Struct kas_theme::Colors[][src]

pub struct Colors<C> {
Show fields pub background: C, pub frame: C, pub bg: C, pub bg_disabled: C, pub bg_error: C, pub text: C, pub text_sel: C, pub text_sel_bg: C, pub label_text: C, pub button_text: C, pub nav_focus: C, pub button: C, pub button_disabled: C, pub button_highlighted: C, pub button_depressed: C, pub checkbox: C,
}
Provides standard theme colours

Fields

background: C

Background colour

frame: C

Colour for frames (not always used)

bg: C

Background colour of EditBox

bg_disabled: C

Background colour of EditBox (disabled state)

bg_error: C

Background colour of EditBox (error state)

text: C

Text colour in an EditBox

text_sel: C

Selected tect colour

text_sel_bg: C

Selected text background colour

label_text: C

Text colour in a Label

button_text: C

Text colour on a TextButton

nav_focus: C

Highlight colour for keyboard navigation

button: C

Colour of a TextButton

button_disabled: C

Colour of a TextButton (disabled state)

button_highlighted: C

Colour of a TextButton when hovered by the mouse

button_depressed: C

Colour of a TextButton when depressed

checkbox: C

Colour of mark within a CheckBox or RadioBox

Implementations

White background with blue activable items

Light scheme

Dark scheme

Get colour of a text area, depending on state

Get colour for navigation highlight region, if any

Get colour for a button, depending on state

Get colour for a checkbox mark, depending on state

pub fn menu_entry(&self, state: InputState) -> Option<Rgba>[src]

Get background highlight colour of a menu entry, if any

Get colour of a scrollbar, depending on state

Get text colour from class