Struct kas_theme::ShadedTheme [−][src]
pub struct ShadedTheme { /* fields omitted */ }Expand description
A theme using simple shading to give apparent depth to elements
Implementations
Set font size
Units: Points per Em (standard unit of font size)
Set the colour scheme
If no scheme by this name is found the scheme is left unchanged.