Trait kas_theme::Window[][src]

pub trait Window<D: DrawShared>: 'static {
    type SizeHandle: SizeHandle;
    unsafe fn size_handle(&mut self, draw: &mut D) -> Self::SizeHandle;
fn as_any_mut(&mut self) -> &mut dyn Any; }
Per-window storage for the theme

Constructed via Theme::new_window.

The main reason for this separation is to allow proper handling of multi-window applications across screens with differing DPIs.

Associated Types

The associated SizeHandle implementation.

Required methods

Construct a SizeHandle object

The draw reference is guaranteed to be identical to the one used to construct this object.

Implementations on Foreign Types

Implementors