Trait kas_theme::WindowDst[][src]

pub trait WindowDst<D: DrawShared> {
    unsafe fn size_handle(&mut self, draw: &mut D) -> StackDst<dyn SizeHandle>;
fn as_any_mut(&mut self) -> &mut dyn Any; }
As Window, but without associated types

This trait is implemented automatically for all implementations of Window. It is intended only for use where a less parameterised trait is required.

Feature gated: this is only available with feature stack_dst.

Required methods

Construct a SizeHandle object

The draw reference is guaranteed to be identical to the one used to construct this object.

This function is unsafe because the returned object requires a lifetime bound not exceeding that of all three pointers passed in.

Implementors