Trait kas_theme::Window [−][src]
pub trait Window<D: DrawShared>: 'static { type SizeHandle: SizeHandle; unsafe fn size_handle(&mut self, draw: &mut D) -> Self::SizeHandle; fn as_any_mut(&mut self) -> &mut dyn Any; }
Per-window storage for the theme
Constructed via Theme::new_window.
The main reason for this separation is to allow proper handling of multi-window applications across screens with differing DPIs.
Associated Types
type SizeHandle: SizeHandle[src]
type SizeHandle: SizeHandle[src]The associated SizeHandle implementation.
Required methods
unsafe fn size_handle(&mut self, draw: &mut D) -> Self::SizeHandle[src]
unsafe fn size_handle(&mut self, draw: &mut D) -> Self::SizeHandle[src]Construct a SizeHandle object
The draw reference is guaranteed to be identical to the one used to
construct this object.
fn as_any_mut(&mut self) -> &mut dyn Any[src]Implementations on Foreign Types
type SizeHandle = <W as Window<D>>::SizeHandleImplementors
type SizeHandle = SizeHandle<'static, D>type SizeHandle = StackDst<dyn SizeHandle>